@@ -7,15 +7,12 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 use crate::{routing::Peer, section::SectionKeyShare, XorName};
-use bls_signature_aggregator::Proof;
 use bytes::Bytes;
 use hex_fmt::HexFmt;
 use sn_messaging::{
-    node::{
-        DkgFailureProofSet, Proposal, RoutingMsg, SectionAuthorityProvider, SignedRelocateDetails,
-    },
-    section_info::Message as SectionInfoMsg,
-    DestInfo, Itinerary, MessageType,
+    node::{DkgFailureSignedSet, Proposal, RoutingMsg, Signed, SignedRelocateDetails},
+    section_info::SectionInfoMsg,
+    DestInfo, Itinerary, MessageType, SectionAuthorityProvider,
 };
 use std::{
     fmt::{self, Debug, Formatter},
@@ -49,7 +46,7 @@ pub(crate) enum Command {
     /// Handle peer that's been detected as lost.
     HandlePeerLost(SocketAddr),
     /// Handle agreement on a proposal.
-    HandleAgreement { proposal: Proposal, proof: Proof },
+    HandleAgreement { proposal: Proposal, signed: Signed },
     /// Handle the outcome of a DKG session where we are one of the participants (that is, one of
     /// the proposed new elders).
     HandleDkgOutcome {
@@ -57,7 +54,7 @@ pub(crate) enum Command {
         outcome: SectionKeyShare,
     },
     /// Handle a DKG failure that was observed by a majority of the DKG participants.
-    HandleDkgFailure(DkgFailureProofSet),
+    HandleDkgFailure(DkgFailureSignedSet),
     /// Send a message to `delivery_group_size` peers out of the given `recipients`.
     SendMessage {
         recipients: Vec<(XorName, SocketAddr)>,
@@ -85,12 +82,12 @@ pub(crate) enum Command {
     /// Attempt to set JoinsAllowed flag.
     SetJoinsAllowed(bool),
     /// Test peer's connectivity
-    TestConnectivity {
+    ProposeOnline {
         peer: Peer,
         // Previous name if relocated.
         previous_name: Option<XorName>,
         // The key of the destination section that the joining node knows, if any.
-        their_knowledge: Option<bls::PublicKey>,
+        destination_key: Option<bls::PublicKey>,
     },
     /// Proposes a peer as offline
     ProposeOffline(XorName),
@@ -149,10 +146,10 @@ impl Debug for Command {
                 f.debug_tuple("HandleConnectionLost").field(addr).finish()
             }
             Self::HandlePeerLost(addr) => f.debug_tuple("HandlePeerLost").field(addr).finish(),
-            Self::HandleAgreement { proposal, proof } => f
+            Self::HandleAgreement { proposal, signed } => f
                 .debug_struct("HandleAgreement")
                 .field("proposal", proposal)
-                .field("proof.public_key", &proof.public_key)
+                .field("signed.public_key", &signed.public_key)
                 .finish(),
             Self::HandleDkgOutcome {
                 section_auth,
@@ -162,8 +159,8 @@ impl Debug for Command {
                 .field("section_auth", section_auth)
                 .field("outcome", &outcome.public_key_set.public_key())
                 .finish(),
-            Self::HandleDkgFailure(proofs) => {
-                f.debug_tuple("HandleDkgFailure").field(proofs).finish()
+            Self::HandleDkgFailure(signeds) => {
+                f.debug_tuple("HandleDkgFailure").field(signeds).finish()
             }
             Self::SendMessage {
                 recipients,
@@ -203,12 +200,12 @@ impl Debug for Command {
                 .debug_tuple("SetJoinsAllowed")
                 .field(joins_allowed)
                 .finish(),
-            Self::TestConnectivity {
+            Self::ProposeOnline {
                 peer,
                 previous_name,
                 ..
             } => f
-                .debug_struct("TestConnectivity")
+                .debug_struct("ProposeOnline")
                 .field("peer", peer)
                 .field("previous_name", previous_name)
                 .finish(),
