@@ -14,35 +14,31 @@ mod resource_proof;
 
 use super::super::Core;
 use crate::{
-    agreement::{DkgCommands, ProofShare, ProposalError},
+    agreement::{DkgCommands, ProposalError, SignedShare},
     error::{Error, Result},
     event::Event,
     messages::{MessageStatus, RoutingMsgUtils, SrcAuthorityUtils, VerifyStatus},
     network::NetworkUtils,
     peer::PeerUtils,
     relocation::{RelocatePayloadUtils, RelocateState, SignedRelocateDetailsUtils},
-    routing::{comm, command::Command},
+    routing::command::Command,
     section::{
         SectionAuthorityProviderUtils, SectionKeyShare, SectionPeersUtils, SectionUtils,
         FIRST_SECTION_MAX_AGE, FIRST_SECTION_MIN_AGE, MIN_ADULT_AGE,
     },
 };
-use bls_signature_aggregator::Error as AggregatorError;
 use bytes::Bytes;
+use sn_messaging::node::Error as AggregatorError;
 use sn_messaging::{
     client::ClientMsg,
     node::{
-        DkgFailureProofSet, JoinRequest, Network, Peer, Proposal, RoutingMsg, Section,
-        SectionAuthorityProvider, SignedRelocateDetails, SrcAuthority, Variant,
+        DkgFailureSignedSet, JoinRejectionReason, JoinRequest, JoinResponse, Network, Peer,
+        Proposal, RoutingMsg, Section, SignedRelocateDetails, SrcAuthority, Variant,
     },
-    section_info::{GetSectionResponse, Message as SectionInfoMsg, SectionInfo},
-    DestInfo, DstLocation, EndUser, MessageType,
-};
-use std::{
-    collections::BTreeSet,
-    iter,
-    net::{IpAddr, SocketAddr},
+    section_info::{GetSectionResponse, SectionInfoMsg},
+    DestInfo, DstLocation, EndUser, MessageType, SectionAuthorityProvider,
 };
+use std::{collections::BTreeSet, iter, net::SocketAddr};
 use xor_name::XorName;
 
 // Message handling
@@ -56,7 +52,7 @@ impl Core {
         let mut commands = vec![];
 
         // Check if the message is for us.
-        let in_dst_location = msg.dst().contains(&self.node.name(), self.section.prefix());
+        let in_dst_location = msg.dst.contains(&self.node.name(), self.section.prefix());
         // TODO: Broadcast message to our section when src is a Node as nodes might not know
         // all the elders in our section and the msg needs to be propagated.
         if !in_dst_location {
@@ -98,54 +94,42 @@ impl Core {
         sender: SocketAddr,
         message: SectionInfoMsg,
         dest_info: DestInfo, // The DestInfo contains the XorName of the sender and a random PK during the initial SectionQuery,
-        our_local_ip: IpAddr,
     ) -> Vec<Command> {
-        // Provide our PK as the dest PK, only redundant as the message itself contains details regarding relocation/registration.
+        // Provide our PK as the dest PK, only redundant as the message
+        // itself contains details regarding relocation/registration.
         let dest_info = DestInfo {
             dest: dest_info.dest,
             dest_section_pk: *self.section().chain().last_key(),
         };
-        match message {
-            SectionInfoMsg::GetSectionQuery {
-                public_key,
-                is_node,
-            } => {
-                let name = XorName::from(public_key);
-                let response =
-                    if is_node && comm::is_reachable(our_local_ip, &sender).await.is_err() {
-                        GetSectionResponse::NodeNotReachable
-                    } else {
-                        debug!("Received GetSectionQuery({}) from {}", name, sender);
 
-                        if let (true, Ok(pk_set)) =
-                            (self.section.prefix().matches(&name), self.public_key_set())
-                        {
-                            GetSectionResponse::Success(SectionInfo {
-                                prefix: self.section.authority_provider().prefix(),
-                                pk_set,
-                                elders: self
-                                    .section
-                                    .authority_provider()
-                                    .peers()
-                                    .map(|peer| (*peer.name(), *peer.addr()))
-                                    .collect(),
-                                joins_allowed: self.joins_allowed,
-                            })
-                        } else {
-                            // If we are elder, we should know a section that is closer to `name` that us.
-                            // Otherwise redirect to our elders.
-                            let section_auth = self
-                                .network
-                                .closest(&name)
-                                .unwrap_or_else(|| self.section.authority_provider());
-                            let targets = section_auth
-                                .elders()
-                                .iter()
-                                .map(|(name, addr)| (*name, *addr))
-                                .collect();
-                            GetSectionResponse::Redirect(targets)
-                        }
-                    };
+        match message {
+            SectionInfoMsg::GetSectionQuery(public_key) => {
+                let name = XorName::from(public_key);
+
+                debug!("Received GetSectionQuery({}) from {}", name, sender);
+
+                let response = if let (true, Ok(pk_set)) =
+                    (self.section.prefix().matches(&name), self.public_key_set())
+                {
+                    GetSectionResponse::Success(SectionAuthorityProvider {
+                        prefix: self.section.authority_provider().prefix(),
+                        public_key_set: pk_set,
+                        elders: self
+                            .section
+                            .authority_provider()
+                            .peers()
+                            .map(|peer| (*peer.name(), *peer.addr()))
+                            .collect(),
+                    })
+                } else {
+                    // If we are elder, we should know a section that is closer to `name` that us.
+                    // Otherwise redirect to our elders.
+                    let section_auth = self
+                        .network
+                        .closest(&name)
+                        .unwrap_or_else(|| self.section.authority_provider());
+                    GetSectionResponse::Redirect(section_auth.clone())
+                };
 
                 let response = SectionInfoMsg::GetSectionResponse(response);
                 debug!("Sending {:?} to {}", response, sender);
@@ -191,11 +175,11 @@ impl Core {
     pub(crate) fn handle_proposal(
         &mut self,
         proposal: Proposal,
-        proof_share: ProofShare,
+        signed_share: SignedShare,
     ) -> Result<Vec<Command>> {
-        match self.proposal_aggregator.add(proposal, proof_share) {
-            Ok((proposal, proof)) => Ok(vec![Command::HandleAgreement { proposal, proof }]),
-            Err(ProposalError::Aggregation(bls_signature_aggregator::Error::NotEnoughShares)) => {
+        match self.proposal_aggregator.add(proposal, signed_share) {
+            Ok((proposal, signed)) => Ok(vec![Command::HandleAgreement { proposal, signed }]),
+            Err(ProposalError::Aggregation(sn_messaging::node::Error::NotEnoughShares)) => {
                 Ok(vec![])
             }
             Err(error) => {
@@ -225,20 +209,20 @@ impl Core {
         result
     }
 
-    pub(crate) fn handle_dkg_failure(&mut self, proofs: DkgFailureProofSet) -> Result<Command> {
-        let variant = Variant::DkgFailureAgreement(proofs);
+    pub(crate) fn handle_dkg_failure(&mut self, signeds: DkgFailureSignedSet) -> Result<Command> {
+        let variant = Variant::DkgFailureAgreement(signeds);
         let message = RoutingMsg::single_src(
             &self.node,
             DstLocation::DirectAndUnrouted,
             variant,
-            self.section.authority_provider().section_key,
+            self.section.authority_provider().section_key(),
         )?;
         Ok(self.send_message_to_our_elders(message))
     }
 
     pub(crate) fn aggregate_message(&mut self, msg: RoutingMsg) -> Result<Option<RoutingMsg>> {
-        let proof_share = if let SrcAuthority::BlsShare { proof_share, .. } = msg.src() {
-            proof_share
+        let signed_share = if let SrcAuthority::BlsShare { signed_share, .. } = &msg.src {
+            signed_share
         } else {
             // Not an aggregating message, return unchanged.
             return Ok(Some(msg));
@@ -248,11 +232,11 @@ impl Core {
             bincode::serialize(&msg.signable_view()).map_err(|_| Error::InvalidMessage)?;
         match self
             .message_aggregator
-            .add(&signed_bytes, proof_share.clone())
+            .add(&signed_bytes, signed_share.clone())
         {
-            Ok(proof) => {
+            Ok(signed) => {
                 trace!("Successfully accumulated signatures for message: {:?}", msg);
-                Ok(Some(msg.into_dst_accumulated(proof)?))
+                Ok(Some(msg.into_dst_accumulated(signed)?))
             }
             Err(AggregatorError::NotEnoughShares) => Ok(None),
             Err(err) => {
@@ -348,29 +332,27 @@ impl Core {
             }
             Variant::DkgFailureObservation {
                 dkg_key,
-                proof,
+                signed,
                 non_participants,
-            } => self.handle_dkg_failure_observation(*dkg_key, non_participants, *proof),
-            Variant::DkgFailureAgreement(proofs) => {
-                self.handle_dkg_failure_agreement(&msg.src.name(), proofs)
+            } => self.handle_dkg_failure_observation(*dkg_key, non_participants, *signed),
+            Variant::DkgFailureAgreement(signeds) => {
+                self.handle_dkg_failure_agreement(&msg.src.name(), signeds)
             }
             Variant::Propose {
                 content,
-                proof_share,
+                signed_share,
             } => {
                 let mut commands = vec![];
-                let result = self.handle_proposal(content.clone(), proof_share.clone());
+                let result = self.handle_proposal(content.clone(), signed_share.clone());
 
                 if let Some(addr) = sender {
-                    commands.extend(self.check_lagging((src_name, addr), proof_share)?);
+                    commands.extend(self.check_lagging((src_name, addr), signed_share)?);
                 }
 
                 commands.extend(result?);
                 Ok(commands)
             }
-            Variant::NodeApproval { .. }
-            | Variant::JoinRetry { .. }
-            | Variant::ResourceChallenge { .. } => {
+            Variant::JoinResponse(_) => {
                 if let Some(RelocateState::InProgress(message_tx)) = &mut self.relocate_state {
                     if let Some(sender) = sender {
                         trace!("Forwarding {:?} to the bootstrap task", msg);
@@ -421,7 +403,7 @@ impl Core {
             self.node(),
             dst_location,
             variant,
-            self.section.authority_provider().section_key,
+            self.section.authority_provider().section_key(),
         )?;
         let key = self.section_key_by_name(&src_name);
         Ok(Command::send_message_to_node(
@@ -429,20 +411,22 @@ impl Core {
             msg,
             DestInfo {
                 dest: src_name,
-                dest_section_pk: *key,
+                dest_section_pk: key,
             },
         ))
     }
 
     pub(crate) fn verify_message(&self, msg: &RoutingMsg) -> Result<bool> {
-        let known_keys = self
+        let known_keys: Vec<bls::PublicKey> = self
             .section
             .chain()
             .keys()
+            .copied()
             .chain(self.network.keys().map(|(_, key)| key))
-            .chain(iter::once(self.section.genesis_key()));
+            .chain(iter::once(*self.section.genesis_key()))
+            .collect();
 
-        match msg.verify(known_keys) {
+        match msg.verify(known_keys.iter()) {
             Ok(VerifyStatus::Full) => Ok(true),
             Ok(VerifyStatus::Unknown) => Ok(false),
             Err(error) => {
@@ -461,17 +445,17 @@ impl Core {
         if let DstLocation::EndUser(EndUser {
             xorname: xor_name,
             socket_id,
-        }) = msg.dst()
+        }) = msg.dst
         {
-            if let Some(socket_addr) = self.get_socket_addr(*socket_id).copied() {
+            if let Some(socket_addr) = self.get_socket_addr(socket_id).copied() {
                 trace!("sending user message {:?} to client {:?}", msg, socket_addr);
                 return Ok(vec![Command::SendMessage {
-                    recipients: vec![(*xor_name, socket_addr)],
+                    recipients: vec![(xor_name, socket_addr)],
                     delivery_group_size: 1,
                     message: MessageType::Client {
                         msg: ClientMsg::from(content)?,
                         dest_info: DestInfo {
-                            dest: *xor_name,
+                            dest: xor_name,
                             dest_section_pk: *self.section.chain().last_key(),
                         },
                     },
@@ -488,9 +472,9 @@ impl Core {
         self.send_event(Event::MessageReceived {
             content,
             src: msg.src.src_location(),
-            dst: *msg.dst(),
-            proof: msg.proof(),
-            section_pk: msg.section_pk(),
+            dst: msg.dst,
+            signed: msg.signed(),
+            section_pk: msg.section_pk,
         })
         .await;
 
@@ -553,20 +537,18 @@ impl Core {
     ) -> Result<Vec<Command>> {
         debug!("Received {:?} from {}", join_request, peer);
 
-        if !self.section.prefix().matches(peer.name()) {
+        if !self.section.prefix().matches(peer.name())
+            || join_request.section_key != *self.section.chain().last_key()
+        {
             debug!(
-                "Ignoring JoinRequest from {} - name doesn't match our prefix {:?}.",
+                "JoinRequest from {} - name doesn't match our prefix {:?}.",
                 peer,
                 self.section.prefix()
             );
-            return Ok(vec![]);
-        }
 
-        if join_request.section_key != *self.section.chain().last_key() {
-            let variant = Variant::JoinRetry {
-                section_auth: self.section.authority_provider().clone(),
-                section_key: *self.section.chain().last_key(),
-            };
+            let variant = Variant::JoinResponse(Box::new(JoinResponse::Retry(
+                self.section.authority_provider().clone(),
+            )));
             trace!("Sending {:?} to {}", variant, peer);
             return Ok(vec![self.send_direct_message(
                 (*peer.name(), *peer.addr()),
@@ -584,7 +566,7 @@ impl Core {
         }
 
         // This joining node is being relocated to us.
-        let (mut age, previous_name, their_knowledge) =
+        let (mut age, previous_name, destination_key) =
             if let Some(ref payload) = join_request.relocate_payload {
                 if !payload.verify_identity(peer.name()) {
                     debug!(
@@ -622,12 +604,20 @@ impl Core {
                 )
             } else if !self.joins_allowed {
                 debug!(
-                    "Ignoring JoinRequest from {} - new node not acceptable.",
+                    "Rejecting JoinRequest from {} - joins currently not allowed.",
                     peer,
                 );
-                return Ok(vec![]);
+                let variant = Variant::JoinResponse(Box::new(JoinResponse::Rejected(
+                    JoinRejectionReason::JoinsDisallowed,
+                )));
+                trace!("Sending {:?} to {}", variant, peer);
+                return Ok(vec![self.send_direct_message(
+                    (*peer.name(), *peer.addr()),
+                    variant,
+                    *self.section.chain().last_key(),
+                )?]);
             } else {
-                // Start as Adult as long as passed resource proofing.
+                // Start as Adult as long as passed resource signeding.
                 (MIN_ADULT_AGE, None, None)
             };
 
@@ -667,12 +657,12 @@ impl Core {
             return Ok(vec![]);
         }
 
-        // Require resource proof only if joining as a new node.
+        // Require resource signed only if joining as a new node.
         if previous_name.is_none() {
             if let Some(response) = join_request.resource_proof_response {
                 if !self.validate_resource_proof_response(peer.name(), response) {
                     debug!(
-                        "Ignoring JoinRequest from {} - invalid resource proof response",
+                        "Ignoring JoinRequest from {} - invalid resource signed response",
                         peer
                     );
                     return Ok(vec![]);
@@ -682,10 +672,10 @@ impl Core {
             }
         }
 
-        Ok(vec![Command::TestConnectivity {
+        Ok(vec![Command::ProposeOnline {
             peer,
             previous_name,
-            their_knowledge,
+            destination_key,
         }])
     }
 
@@ -700,24 +690,4 @@ impl Core {
 
         Ok(commands)
     }
-
-    /* FIXME: bring back unresponsiveness detection
-    // Detect non-responsive peers and vote them out.
-    pub(crate) fn vote_for_remove_unresponsive_peers(&mut self, core: &mut Core) -> Result<()> {
-        let unresponsive_nodes: Vec<_> = self
-            .consensus_engine
-            .detect_unresponsive(self.shared_state.our_info())
-            .into_iter()
-            .filter_map(|id| self.shared_state.our_members.get(id.name()))
-            .map(|info| info.clone().leave())
-            .collect();
-
-        for info in unresponsive_nodes {
-            info!("Voting for unresponsive node {}", info.peer);
-            self.cast_unordered_vote(core, Vote::Offline(info))?;
-        }
-
-        Ok(())
-    }
-    */
 }
